/* Fo
 * fo-all-area.h: Header file that includes header files for all area
 *                  objects
 *
 * Copyright (C) 2001 Sun Microsystems
 * Copyright (C) 2007 Menteith Consulting Ltd
 *
 * See COPYING for the status of this software.
 */

#ifndef __FO_ALL_AREA_H__
#define __FO_ALL_AREA_H__

G_BEGIN_DECLS

#include <libfo/area/fo-area.h>

/* area objects */
#include <libfo/area/fo-area-area.h>
#include <libfo/area/fo-area-layout.h>
#include <libfo/area/fo-area-list-item.h>
#include <libfo/area/fo-area-normal.h>
#include <libfo/area/fo-area-page.h>
#include <libfo/area/fo-area-reference.h>
#include <libfo/area/fo-area-spanning-table-cell.h>
#include <libfo/area/fo-area-table-body.h>
#include <libfo/area/fo-area-table-cell-proxy.h>
#include <libfo/area/fo-area-table-cell.h>
#include <libfo/area/fo-area-table-continuation.h>
#include <libfo/area/fo-area-table-footer.h>
#include <libfo/area/fo-area-table-header.h>
#include <libfo/area/fo-area-table-part.h>
#include <libfo/area/fo-area-table-row.h>
#include <libfo/area/fo-area-table.h>
#include <libfo/area/fo-area-tree.h>
#include <libfo/area/fo-area-viewport-reference.h>

G_END_DECLS


#endif /* !__FO_ALL_AREA_H__ */
